;; Generated package description from elisp-benchmarks.el  -*- no-byte-compile: t -*-
(define-package "elisp-benchmarks" "1.15.0.20240515.183707" "elisp benchmarks collection" 'nil :commit "0eb498f77b5078849231468848ad73185989185e" :url "https://elpa.gnu.org/packages/elisp-benchmarks.html" :authors '(("Andrea Corallo" . "acorallo@gnu.org")) :maintainer '("Andrea Corallo" . "acorallo@gnu.org") :keywords '("languages" "lisp"))
